#!/bin/bash

# cdvdlabel.sh
#
# Usage: cdvdlabel.sh <device file> <label file> <log file>
#
# Error Return Codes:
# 1 - No label found
# 2 - Major failure
#
# Author: C. Schuck
#
# 05/20/2003  P. Provost  Changed to use grep -q
# 03/17/2005  P. Provost  Fixed tracing

DEVICEFILE=$1
LABELFILE=$2
LOGFILE=$3

echo "-> cdvdlabel.sh" >> $LOGFILE
echo "cdvdlabel.sh: Getting the label from the CD-ROM or DVD-RAM at $DEVICEFILE for `date`" >> $LOGFILE

actzTrace "XMDA   T: -> cdvdlabel.sh"
actzTrace "XMDA   F: cdvdlabel.sh: Getting the label from the CD-ROM or DVD-RAM at $DEVICEFILE for `date`"

# First try to retrieve the CD-ROM or DVD-RAM label using chkudf
if chkudf $DEVICEFILE > $LABELFILE 2>&1; then
    
    if ! grep -q -i 'Volume Identifier:' $LABELFILE 2>&1; then
        
        echo "cdvdlabel.sh: Failed to retrieve the label using chkudf...possibly a CD-ROM or not UDF formatted" >> $LOGFILE
        actzTrace "XMDA   F: cdvdlabel.sh: Failed to retrieve the label using chkudf...possibly a CD-ROM or not UDF formatted"
        
        # If the media is a CD-ROM, then try to retrieve the CD-ROM label using the dd command 
        if dd if=$DEVICEFILE bs=1 skip=32808 count=32 > $LABELFILE 2>&1; then
              
            echo "cdvdlabel.sh: Successfully retrieved the label using dd." >> $LOGFILE
            actzTrace "XMDA   F: cdvdlabel.sh: Successfully retrieved the label using dd."
            
            echo "cdvdlabel.sh: Label File Listing:" >> $LOGFILE
            cat $LABELFILE >> $LOGFILE
        
        else
                         
            echo "cdvdlabel.sh: Failed to retrieve the label using dd." >> $LOGFILE
            actzTrace "XMDA   F: cdvdlabel.sh: Failed to retrieve the label using dd."
            
            echo "<- cdvdlabel.sh" >> $LOGFILE
            echo "" >> $LOGFILE

            actzTrace "XMDA   T: <- cdvdlabel.sh"            
            
            exit 1
        fi
    else
        cp $LABELFILE /tmp/console/mediasvc/cdvdlabel.out
        grep -i '(M) Volume Identifier:' /tmp/console/mediasvc/cdvdlabel.out > $LABELFILE
        rm -f /tmp/console/mediasvc/cdvdlabel.out
        
        echo "cdvdlabel.sh: Successfully retrieved label using chkudf." >> $LOGFILE    
        actzTrace "XMDA   F: cdvdlabel.sh: Successfully retrieved label using chkudf."
        
        echo "cdvdlabel.sh: Label File Listing:" >> $LOGFILE
        cat $LABELFILE >> $LOGFILE
    fi
else
    
    echo "cdvdlabel.sh: Failed to retrieve the label using chkudf." >> $LOGFILE
    actzTrace "XMDA   F: cdvdlabel.sh: Failed to retrieve the label using chkudf."

    echo "<- cdvdlabel.sh" >> $LOGFILE
    echo "" >> $LOGFILE

    actzTrace "XMDA   T: <- cdvdlabel.sh"
    
    exit 2
fi

echo "<- cdvdlabel.sh" >> $LOGFILE
echo "" >> $LOGFILE

actzTrace "XMDA   T: <- cdvdlabel.sh"

exit 0

